@@ -25,11 +25,11 @@ class petarInterface(
     """
     Parallel, Particle-Particle & Particle-Tree & Few-body integration module
 
-    .. [#] Namekata D., et al., 2018, PASJ, 70, 70
-    .. [#] Iwasawa M., Tanikawa A., Hosono N., Nitadori K., Muranushi T., Makino J., 2016, PASJ, 68, 54
-    .. [#] Iwasawa M., Portegies Zwart S., Makino J., 2015, ComAC, 2, 6
-    .. [#] Wang, L., Nitadori, K., Makino, J., 2020, MNRAS, 493, 3398
-    .. [#] Wang, L., Iwasawa, M., Nitadori, K., Makino, J., 2020, MNRAS, accepted, ArXiv: 2006.16560 [astro-ph]
+    .. [#] ADS:2020MNRAS.497..536W (Wang, L., Iwasawa, M., Nitadori, K., Makino, J., 2020, MNRAS, 497, 536)
+    .. [#] ADS:2020MNRAS.493.3398W (Wang, L., Nitadori, K., Makino, J., 2020, MNRAS, 493, 3398)
+    .. [#] ADS:2018PASJ...70...70N (Namekata D., et al., 2018, PASJ, 70, 70)
+    .. [#] ADS:2016PASJ...68...54I (Iwasawa M., Tanikawa A., Hosono N., Nitadori K., Muranushi T., Makino J., 2016, PASJ, 68, 54)
+    .. [#] ADS:2015ComAC...2....6I (Iwasawa M., Portegies Zwart S., Makino J., 2015, ComAC, 2, 6)
     """
 
     include_headers = ['interface.h']
